@@ -17,11 +17,15 @@ from pathlib import Path
 from pandas import DataFrame
 from ast import literal_eval
 
-from IPython.display import display
 from jinja2 import Environment, PackageLoader
 
 from ads.common import oci_client, auth, logger
 from ads.common.utils import FileOverwriteError
+from ads.common.decorator.runtime_dependency import (
+    runtime_dependency,
+    OptionalDependency,
+)
+from ads.common.decorator.deprecate import deprecated
 
 from oci.data_flow.models import (
     CreateApplicationDetails,
@@ -57,6 +61,7 @@ class SPARK_VERSION(str):
 
 
 class DataFlow:
+    @deprecated("2.6.3")
     def __init__(
         self,
         compartment_id=None,
@@ -149,10 +154,13 @@ class DataFlow:
             )
             return df
 
+        @runtime_dependency(module="IPython", install_from=OptionalDependency.NOTEBOOK)
         def show_in_notebook(app_self):
             """
             Describe the project by showing its properties
             """
+            from IPython.display import display
+
             display(app_self)
 
         def _repr_html_(app_self):
@@ -941,6 +949,7 @@ class DataFlow:
 
 
 class DataFlowApp(DataFlow):
+    @deprecated("2.6.3")
     def __init__(self, app_config, app_response, app_dir, oci_link, **kwargs):
         super().__init__(compartment_id=app_config["compartment_id"], **kwargs)
         self._config = app_config
@@ -975,10 +984,13 @@ class DataFlowApp(DataFlow):
             )
             return df
 
+        @runtime_dependency(module="IPython", install_from=OptionalDependency.NOTEBOOK)
         def show_in_notebook(run_self):
             """
             Describe the project by showing it's properties
             """
+            from IPython.display import display
+
             display(run_self)
 
         def _repr_html_(run_self):
@@ -1377,6 +1389,7 @@ class DataFlowApp(DataFlow):
 
 
 class RunObserver:
+    @deprecated("2.6.3")
     def __init__(self, app, run_config, save_log_to_local):
         self.app = app
         self._config = run_config
@@ -1562,6 +1575,7 @@ class RunObserver:
 class DataFlowRun(DataFlow):
     LOG_OUTPUTS = ["stdout", "stderr"]
 
+    @deprecated("2.6.3")
     def __init__(
         self, run_config, run_response, save_log_to_local, local_dir, **kwargs
     ):
@@ -1730,6 +1744,7 @@ class DataFlowRun(DataFlow):
 
 
 class DataFlowLog:
+    @deprecated("2.6.3")
     def __init__(self, text, oci_path, log_local_dir):
         self.text = str(text)
         self._oci_path = oci_path
