@@ -9,13 +9,14 @@ import ast
 import json
 import logging
 import os
+import re
 import shutil
 import tempfile
 import zipfile
 from typing import Tuple
 from urllib.parse import urlparse
-import re
 
+import oci
 import requests
 import yaml
 
@@ -124,6 +125,14 @@ def model_deployment_find_fields(cfg) -> None:
             model_deployment_find_fields(value)
 
 
+def get_object_storage_client():
+    try:
+        config = oci.auth.signers.get_resource_principals_signer()
+    except:
+        config = oci.config.from_file()
+    return oci.object_storage.ObjectStorageClient(config)
+
+
 def check_runtime_yml(file_path) -> Tuple[bool, str]:
     """
     Check runtime yaml mandatory fields
@@ -159,12 +168,12 @@ def check_runtime_yml(file_path) -> Tuple[bool, str]:
         m = re.match(PYTHON_VER_PATTERN, str(TESTS["runtime_env_python"]["value"]))
         if m and m.group():
             TESTS["runtime_env_python"]["success"] = True
+            env_path = urlparse(TESTS["runtime_env_path"]["value"])
+
             if VARIABLES["runtime_env_type"] == "data_science":
                 response = requests.request("GET", PAR_URL)
                 if response.ok:
                     service_pack_list = response.json().get("service_packs")
-
-                    env_path = urlparse(TESTS["runtime_env_path"]["value"])
                     service_pack = None
                     for service_pack_item in service_pack_list:
                         pack_path = urlparse(service_pack_item["pack_path"])
@@ -185,8 +194,36 @@ def check_runtime_yml(file_path) -> Tuple[bool, str]:
                 else:
                     TESTS["runtime_path_exist"]["success"] = False
                     return False, TESTS["runtime_path_exist"]["error_msg"]
-            elif TESTS["runtime_env_path"]["value"]:
-                return True, True
+            else:
+                bucket_name = env_path.username
+                namespace = env_path.hostname
+                object_name = env_path.path.strip("/")
+                if bucket_name != None and namespace != None and object_name != None:
+                    try:
+                        object_storage_client = get_object_storage_client()
+                        head_object_response = object_storage_client.head_object(
+                            namespace_name=namespace,
+                            bucket_name=bucket_name,
+                            object_name=object_name,
+                            version_id=None,
+                            if_match=None,
+                            if_none_match=None,
+                            opc_client_request_id=None,
+                            opc_sse_customer_algorithm=None,
+                            opc_sse_customer_key=None,
+                            opc_sse_customer_key_sha256=None,
+                        )
+                        TESTS["runtime_path_exist"]["success"] = True
+                        return True, True
+                    except Exception as e:
+                        TESTS["runtime_path_exist"]["success"] = None
+                        TESTS["runtime_path_exist"][
+                            "error_msg"
+                        ] = "WARNING: Unable to validate if INFERENCE_ENV_PATH exists. Please check whether provided path is correct or user is authorized to access the file"
+                        return False, TESTS["runtime_path_exist"]["error_msg"]
+                else:
+                    TESTS["runtime_path_exist"]["success"] = False
+                    return False, TESTS["runtime_path_exist"]["error_msg"]
         else:
             logger.error(f"Mismatch in python version")
             TESTS["runtime_env_python"]["success"] = False
@@ -349,8 +386,9 @@ def write_html(output_path) -> None:
     for key, value in TESTS.items():
         result = get_test_result(key)
         html_response += f'<tr class="{css_classes[result]}"><th class="{count_classes[count%2]}">{count}</th><td>{key}</td><td>{TESTS[key]["description"]}</td><td>{out_classes[result]}</td>'
-
-        if get_test_result(key) == 1:
+        if get_test_result(key) == 1 or (
+            key == "runtime_path_exist" and "WARNING" in TESTS[key]["error_msg"]
+        ):
             html_response += f'<td>{TESTS[key]["error_msg"]}</td></tr></body>'
         else:
             html_response += f"<td> </td></tr></body>"
